@@ -12,8 +12,6 @@ from imageanalysis.ui.data_view.image_tool.color_mapping import \
     ColorMapController
 
 
-# TODO: Updated documentation
-
 class ImageTool(DockArea):
     """Handles image visualization and manipulation."""
 
@@ -62,8 +60,8 @@ class ImageTool(DockArea):
         )
 
         # Child widgets
-        self.plot_3d = ImagePlot(parent=self, dock=self.plot_3d_dock)
-        self.plot_2d = ImagePlot(parent=self, dock=self.plot_2d_dock)
+        self.plot_3d = ImagePlot(parent=self, dock=self.plot_3d_dock, n_dim=3)
+        self.plot_2d = ImagePlot(parent=self, dock=self.plot_2d_dock, n_dim=2)
         self.plot_1d = LinePlot(parent=self, dock=self.plot_1d_dock)
         self.controller = ImageToolController(
             parent=self,
@@ -291,7 +289,7 @@ class ImagePlot(pg.ImageView):
 
     updated = QtCore.pyqtSignal()
 
-    def __init__(self, parent, dock) -> None:
+    def __init__(self, parent, dock, n_dim) -> None:
         super(ImagePlot, self).__init__(
             imageItem=pg.ImageItem(),
             view=pg.PlotItem()
@@ -301,10 +299,11 @@ class ImagePlot(pg.ImageView):
         self.image_tool = parent
         self.controller = None
         self.dock = dock
+        self.n_dim = n_dim
 
         # Class variables for plotting
         self.data = None
-        self.image = None
+        self.image_data = None
         self.norm_image = None
         self.x_label, self.y_label = None, None
         self.x_coords, self.y_coords = None, None
@@ -316,15 +315,20 @@ class ImagePlot(pg.ImageView):
         self.ui.menuBtn.hide()
         self.getView().setAspectLocked(False)
         self.getView().ctrlMenu = None
+        self.getView().showGrid(x=True, y=True, alpha=0.5)
 
         # Connections
         self.getView().scene().sigMouseMoved.connect(self._updateMousePoint)
 
     def _hide(self) -> None:
+        """Hides plot and parent dock."""
+
         self.hide()
         self.dock.hide()
 
     def _show(self) -> None:
+        """Shows plot and parent dock."""
+
         self.show()
         self.dock.show()
 
@@ -338,8 +342,9 @@ class ImagePlot(pg.ImageView):
         x_axis: bool=True,
         y_axis: bool=True
     ) -> None:
+        """Normalizes and plots image with proper labels and axes."""
 
-        self.image = image
+        self.image_data = image
         self.x_label = x_label
         self.y_label = y_label
         self.x_coords = x_coords
@@ -348,13 +353,14 @@ class ImagePlot(pg.ImageView):
         self._setLabels(x_label, y_label)
         self._setCoordinates(x_coords, y_coords)
         self._normalizeImage()
+
         self.setImage(
             img=self.norm_image,
             autoRange=False,
             autoLevels=False,
             transform=self.transform
         )
-
+        
         if x_axis:
             self.getView().showAxis("bottom")
         else:
@@ -368,17 +374,20 @@ class ImagePlot(pg.ImageView):
         self.updated.emit()
 
     def _normalizeImage(self) -> None:
+        """Normalizes image values for color mapping."""
 
-        image = np.copy(self.image)
+        image = np.copy(self.image_data)
         if self.image_tool.color_map_range is None:
             norm_max = 1
         else:
             norm_max = self.image_tool.color_map_range[-1]
         image[image > norm_max] = norm_max
+        image[image == 0] = np.NAN
         image = image / norm_max
         self.norm_image = image
 
     def _setLabels(self, x_label, y_label) -> None:
+        """Sets x and y axis labels."""
 
         if x_label is not None and type(x_label) == str:
             self.x_label = x_label
@@ -388,6 +397,7 @@ class ImagePlot(pg.ImageView):
             self.getView().setLabel("left", y_label)
 
     def _setCoordinates(self, x_coords, y_coords) -> None:
+        """Adjusts image position and scaling."""
 
         self.transform = QtGui.QTransform()
         if x_coords is not None:
@@ -395,8 +405,8 @@ class ImagePlot(pg.ImageView):
         else:
             self.x_coords = np.linspace(
                 start=0,
-                stop=self.image.shape[0] - 1,
-                num=self.image.shape[0],
+                stop=self.image_data.shape[0] - 1,
+                num=self.image_data.shape[0],
                 endpoint=False
             )
 
@@ -405,8 +415,8 @@ class ImagePlot(pg.ImageView):
         else:
             self.y_coords = np.linspace(
                 start=0,
-                stop=self.image.shape[1] - 1,
-                num=self.image.shape[1],
+                stop=self.image_data.shape[1] - 1,
+                num=self.image_data.shape[1],
                 endpoint=False
             )
 
@@ -419,6 +429,7 @@ class ImagePlot(pg.ImageView):
         self.transform.scale(*scale)
 
     def _updateMousePoint(self, scene_point=None) -> None:
+        """Updates mouse coordinates."""
 
         if self.controller is None:
             self.controller = self.image_tool.controller
@@ -426,20 +437,20 @@ class ImagePlot(pg.ImageView):
         if scene_point is not None:
             view_point = self.getView().vb.mapSceneToView(scene_point)
             x_point = int(
-                self.image.shape[0] * (
+                self.image_data.shape[0] * (
                     (view_point.x() - self.x_coords[0]) /
                     (self.x_coords[-1] - self.x_coords[0])
                 )
             )
             y_point = int(
-                self.image.shape[1] * (
+                self.image_data.shape[1] * (
                     (view_point.y() - self.y_coords[0]) /
                     (self.y_coords[-1] - self.y_coords[0])
                 )
             )
             if (
-                0 <= x_point < self.image.shape[0] and
-                0 <= y_point < self.image.shape[1]
+                0 <= x_point < self.image_data.shape[0] and
+                0 <= y_point < self.image_data.shape[1]
             ):
                 self.controller._setMouseInfo(x_point, y_point, sender=self)
             else:
@@ -467,6 +478,30 @@ class LinePlot(pg.PlotWidget):
         self.show()
         self.dock.show()
 
+    def _plot(
+        self,
+        data: np.ndarray=None,
+        x_label: str=None,
+        y_label: str=None,
+        x_coords: np.ndarray=None,
+        y_coords: np.ndarray=None,
+        x_axis: bool=True,
+        y_axis: bool=True
+    ) -> None:
+        """Plots data points as a line."""
+
+        self.plot(data, clear=True)
+
+        if x_axis:
+            self.showAxis("bottom")
+        else:
+            self.hideAxis("bottom")
+
+        if y_axis:
+            self.showAxis("left")
+        else:
+            self.hideAxis("left")
+
 
 class MouseInfoWidget(QtGui.QGroupBox):
     """Handles displaying proper mouse location and associated values."""
